==> danse-2.1.1.tar.gz: danse/src/Entity/EventView.php <==
<?php

namespace Drupal\danse\Entity;

use Drupal\Core\DrupalKernel;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Theme\Registry;
use Drupal\danse\PluginManager;
use Drupal\danse\Query;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * View builder handler for DANSE events.
 */
final class EventView extends EntityViewBuilder {

  /**
   * @var \Drupal\Core\DrupalKernel
   */
  protected $kernel;

  /**
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * @var \Drupal\danse\Query
   */
  protected $query;

  /**
   * @var \Drupal\danse\PluginManager
   */
  protected $pluginManager;

  /**
   * EventView constructor.
   *
   * @param \Drupal\Core\DrupalKernel $kernel
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param \Drupal\danse\Query $query
   * @param \Drupal\danse\PluginManager $plugin_manager
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   * @param \Drupal\Core\Theme\Registry $theme_registry
   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
   */
  public function __construct(DrupalKernel $kernel, Request $request, Query $query, PluginManager $plugin_manager, EntityTypeInterface $entity_type, EntityRepositoryInterface $entity_repository, LanguageManagerInterface $language_manager, Registry $theme_registry = NULL, EntityDisplayRepositoryInterface $entity_display_repository = NULL) {
    parent::__construct($entity_type, $entity_repository, $language_manager, $theme_registry, $entity_display_repository);
    $this->kernel = $kernel;
    $this->request = $request;
    $this->query = $query;
    $this->pluginManager = $plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $container->get('kernel'),
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('danse.query'),
      $container->get('danse.plugin.manager'),
      $entity_type,
      $container->get('entity.repository'),
      $container->get('language_manager'),
      $container->get('theme.registry'),
      $container->get('entity_display.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $build) {
    $session = $this->request->getSession();
    if ($session === NULL) {
      return [];
    }
    /** @var \Drupal\danse\Entity\EventInterface $event */
    $event = $build['#danse_event'];
    $plugin = $this->pluginManager->createInstance($event->getPluginId());
    foreach ($this->query->findEventNotificationsForCurrentUser($event) as $notification) {
      try {
        $notification
          ->markSeen()
          ->save();
      }
      catch (EntityStorageException $e) {
        // TODO: handle exception.
      }
    }

    $response = new RedirectResponse($plugin->getRedirectUrl($event)->toString());
    $session->save();
    $response->prepare($this->request);
    $this->kernel->terminate($this->request, $response);
    $response->send();
    exit;
  }

}

==> danse-2.2.7.tar.gz: danse/src/Entity/EventView.php <==
<?php

namespace Drupal\danse\Entity;

use Drupal\Core\DrupalKernel;
use Drupal\Core\Entity\EntityDisplayRepositoryInterface;
use Drupal\Core\Entity\EntityRepositoryInterface;
use Drupal\Core\Entity\EntityStorageException;
use Drupal\Core\Entity\EntityTypeInterface;
use Drupal\Core\Entity\EntityViewBuilder;
use Drupal\Core\Language\LanguageManagerInterface;
use Drupal\Core\Theme\Registry;
use Drupal\danse\PluginManager;
use Drupal\danse\Query;
use Symfony\Component\DependencyInjection\ContainerInterface;
use Symfony\Component\HttpFoundation\RedirectResponse;
use Symfony\Component\HttpFoundation\Request;

/**
 * View builder handler for DANSE events.
 */
final class EventView extends EntityViewBuilder {

  /**
   * @var \Drupal\Core\DrupalKernel
   */
  protected $kernel;

  /**
   * @var \Symfony\Component\HttpFoundation\Request
   */
  protected $request;

  /**
   * @var \Drupal\danse\Query
   */
  protected $query;

  /**
   * @var \Drupal\danse\PluginManager
   */
  protected $pluginManager;

  /**
   * EventView constructor.
   *
   * @param \Drupal\Core\DrupalKernel $kernel
   * @param \Symfony\Component\HttpFoundation\Request $request
   * @param \Drupal\danse\Query $query
   * @param \Drupal\danse\PluginManager $plugin_manager
   * @param \Drupal\Core\Entity\EntityTypeInterface $entity_type
   * @param \Drupal\Core\Entity\EntityRepositoryInterface $entity_repository
   * @param \Drupal\Core\Language\LanguageManagerInterface $language_manager
   * @param \Drupal\Core\Theme\Registry $theme_registry
   * @param \Drupal\Core\Entity\EntityDisplayRepositoryInterface $entity_display_repository
   */
  public function __construct(DrupalKernel $kernel, Request $request, Query $query, PluginManager $plugin_manager, EntityTypeInterface $entity_type, EntityRepositoryInterface $entity_repository, LanguageManagerInterface $language_manager, Registry $theme_registry = NULL, EntityDisplayRepositoryInterface $entity_display_repository = NULL) {
    parent::__construct($entity_type, $entity_repository, $language_manager, $theme_registry, $entity_display_repository);
    $this->kernel = $kernel;
    $this->request = $request;
    $this->query = $query;
    $this->pluginManager = $plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function createInstance(ContainerInterface $container, EntityTypeInterface $entity_type) {
    return new static(
      $container->get('kernel'),
      $container->get('request_stack')->getCurrentRequest(),
      $container->get('danse.query'),
      $container->get('plugin.manager.danse.plugin'),
      $entity_type,
      $container->get('entity.repository'),
      $container->get('language_manager'),
      $container->get('theme.registry'),
      $container->get('entity_display.repository')
    );
  }

  /**
   * {@inheritdoc}
   */
  public function build(array $build) {
    $session = $this->request->getSession();
    if ($session === NULL) {
      return [];
    }
    /** @var \Drupal\danse\Entity\EventInterface $event */
    $event = $build['#danse_event'];
    $plugin = $this->pluginManager->createInstance($event->getPluginId());
    foreach ($this->query->findEventNotificationsForCurrentUser($event) as $notification) {
      try {
        $notification
          ->markSeen()
          ->save();
      }
      catch (EntityStorageException $e) {
        // TODO: handle exception.
      }
    }

    $response = new RedirectResponse($plugin->getRedirectUrl($event)->toString());
    $session->save();
    $response->prepare($this->request);
    $this->kernel->terminate($this->request, $response);
    $response->send();
    exit;
  }

}
